@@ -21,12 +21,12 @@
  * Look at the README for more information on the program.
  */
 /****************************************************************************
- * MODULE:       R-Tree library 
- *              
+ * MODULE:       R-Tree library
+ *
  * AUTHOR(S):    Antonin Guttman - original code
  *               Melinda Green (melinda@superliminal.com) - major clean-up
  *                               and implementation of bounding spheres
- *               
+ *
  * PURPOSE:      Multidimensional index
  *
  */
@@ -52,10 +52,12 @@
 -----------------------------------------------------------------------------*/
 void Xastir_RTreeInitRect(struct Rect *R)
 {
-	register struct Rect *r = R;
-	register int i;
-	for (i=0; i<NUMSIDES; i++)
-		r->boundary[i] = (RectReal)0;
+  register struct Rect *r = R;
+  register int i;
+  for (i=0; i<NUMSIDES; i++)
+  {
+    r->boundary[i] = (RectReal)0;
+  }
 }
 
 
@@ -65,14 +67,16 @@ void Xastir_RTreeInitRect(struct Rect *R)
 -----------------------------------------------------------------------------*/
 struct Rect Xastir_RTreeNullRect(void)
 {
-	struct Rect r;
-	register int i;
+  struct Rect r;
+  register int i;
 
-	r.boundary[0] = (RectReal)1;
-	r.boundary[NUMDIMS] = (RectReal)-1;
-	for (i=1; i<NUMDIMS; i++)
-		r.boundary[i] = r.boundary[i+NUMDIMS] = (RectReal)0;
-	return r;
+  r.boundary[0] = (RectReal)1;
+  r.boundary[NUMDIMS] = (RectReal)-1;
+  for (i=1; i<NUMDIMS; i++)
+  {
+    r.boundary[i] = r.boundary[i+NUMDIMS] = (RectReal)0;
+  }
+  return r;
 }
 
 
@@ -84,20 +88,20 @@ struct Rect Xastir_RTreeNullRect(void)
 -----------------------------------------------------------------------------*/
 void Xastir_RTreeRandomRect(struct Rect *R)
 {
-	register struct Rect *r = R;
-	register int i;
-	register RectReal width;
-	for (i = 0; i < NUMDIMS; i++)
-	{
-		/* width from 1 to 1000 / 4, more small ones
-		*/
-		width = drand48() * (1000 / 4) + 1;
+  register struct Rect *r = R;
+  register int i;
+  register RectReal width;
+  for (i = 0; i < NUMDIMS; i++)
+  {
+    /* width from 1 to 1000 / 4, more small ones
+    */
+    width = drand48() * (1000 / 4) + 1;
 
-		/* sprinkle a given size evenly but so they stay in [0,100]
-		*/
-		r->boundary[i] = drand48() * (1000-width); /* low side */
-		r->boundary[i + NUMDIMS] = r->boundary[i] + width; // high side
-	}
+    /* sprinkle a given size evenly but so they stay in [0,100]
+    */
+    r->boundary[i] = drand48() * (1000-width); /* low side */
+    r->boundary[i + NUMDIMS] = r->boundary[i] + width; // high side
+  }
 }
 
 
@@ -111,32 +115,32 @@ void Xastir_RTreeRandomRect(struct Rect *R)
 -----------------------------------------------------------------------------*/
 void Xastir_RTreeSearchRect(struct Rect *Search, struct Rect *Data)
 {
-	register struct Rect *search = Search, *data = Data;
-	register int i, j;
-	register RectReal size, center;
+  register struct Rect *search = Search, *data = Data;
+  register int i, j;
+  register RectReal size, center;
 
-	assert(search);
-	assert(data);
+  assert(search);
+  assert(data);
 
-	for (i=0; i<NUMDIMS; i++)
-	{
-		j = i + NUMDIMS;  // index for high side boundary
-		if (data->boundary[i] > -BIG_NUM &&
-		    data->boundary[j] < BIG_NUM)
-		{
-			size = (drand48() * (data->boundary[j] -
-					 data->boundary[i] + 1)) / 2;
-			center = data->boundary[i] + drand48() *
-				(data->boundary[j] - data->boundary[i] + 1);
-			search->boundary[i] = center - size/2;
-			search->boundary[j] = center + size/2;
-		}
-		else  // some open boundary, search entire dimension
-		{
-			search->boundary[i] = -BIG_NUM;
-			search->boundary[j] = BIG_NUM;
-		}
-	}
+  for (i=0; i<NUMDIMS; i++)
+  {
+    j = i + NUMDIMS;  // index for high side boundary
+    if (data->boundary[i] > -BIG_NUM &&
+        data->boundary[j] < BIG_NUM)
+    {
+      size = (drand48() * (data->boundary[j] -
+                           data->boundary[i] + 1)) / 2;
+      center = data->boundary[i] + drand48() *
+               (data->boundary[j] - data->boundary[i] + 1);
+      search->boundary[i] = center - size/2;
+      search->boundary[j] = center + size/2;
+    }
+    else  // some open boundary, search entire dimension
+    {
+      search->boundary[i] = -BIG_NUM;
+      search->boundary[j] = BIG_NUM;
+    }
+  }
 }
 
 #endif
@@ -146,16 +150,17 @@ void Xastir_RTreeSearchRect(struct Rect *Search, struct Rect *Data)
 -----------------------------------------------------------------------------*/
 void Xastir_RTreePrintRect(struct Rect *R, int depth)
 {
-	register struct Rect *r = R;
-	register int i;
-	assert(r);
+  register struct Rect *r = R;
+  register int i;
+  assert(r);
 
-	Xastir_RTreeTabIn(depth);
-	printf("rect:\n");
-	for (i = 0; i < NUMDIMS; i++) {
-		Xastir_RTreeTabIn(depth+1);
-		printf("%f\t%f\n", r->boundary[i], r->boundary[i + NUMDIMS]);
-	}
+  Xastir_RTreeTabIn(depth);
+  printf("rect:\n");
+  for (i = 0; i < NUMDIMS; i++)
+  {
+    Xastir_RTreeTabIn(depth+1);
+    printf("%f\t%f\n", r->boundary[i], r->boundary[i + NUMDIMS]);
+  }
 }
 
 /*-----------------------------------------------------------------------------
@@ -163,18 +168,22 @@ void Xastir_RTreePrintRect(struct Rect *R, int depth)
 -----------------------------------------------------------------------------*/
 RectReal Xastir_RTreeRectVolume(struct Rect *R)
 {
-	register struct Rect *r = R;
-	register int i;
-	register RectReal volume = (RectReal)1;
+  register struct Rect *r = R;
+  register int i;
+  register RectReal volume = (RectReal)1;
 
-	assert(r);
-	if (Undefined(r))
-		return (RectReal)0;
+  assert(r);
+  if (Undefined(r))
+  {
+    return (RectReal)0;
+  }
 
-	for(i=0; i<NUMDIMS; i++)
-		volume *= r->boundary[i+NUMDIMS] - r->boundary[i];
-	assert(volume >= 0.0);
-	return volume;
+  for(i=0; i<NUMDIMS; i++)
+  {
+    volume *= r->boundary[i+NUMDIMS] - r->boundary[i];
+  }
+  assert(volume >= 0.0);
+  return volume;
 }
 
 
@@ -193,42 +202,43 @@ RectReal Xastir_RTreeRectVolume(struct Rect *R)
 /* derived from formule in "Regular Polytopes" by H.S.M Coxeter */
 static double sphere_volume(double dimension)
 {
-	static const double log_pi = log(3.1415926535);
-	double log_gamma, log_volume;
-	log_gamma = gamma(dimension/2.0 + 1);
-	log_volume = dimension/2.0 * log_pi - log_gamma;
-	return exp(log_volume);
+  static const double log_pi = log(3.1415926535);
+  double log_gamma, log_volume;
+  log_gamma = gamma(dimension/2.0 + 1);
+  log_volume = dimension/2.0 * log_pi - log_gamma;
+  return exp(log_volume);
 }
 static const double Xastir_UnitSphereVolume = sphere_volume(NUMDIMS);
 
 #else
 
 /* Precomputed volumes of the unit spheres for the first few dimensions */
-const double Xastir_UnitSphereVolumes[] = {
-	0.000000,  /* dimension   0 */
-	2.000000,  /* dimension   1 */
-	3.141593,  /* dimension   2 */
-	4.188790,  /* dimension   3 */
-	4.934802,  /* dimension   4 */
-	5.263789,  /* dimension   5 */
-	5.167713,  /* dimension   6 */
-	4.724766,  /* dimension   7 */
-	4.058712,  /* dimension   8 */
-	3.298509,  /* dimension   9 */
-	2.550164,  /* dimension  10 */
-	1.884104,  /* dimension  11 */
-	1.335263,  /* dimension  12 */
-	0.910629,  /* dimension  13 */
-	0.599265,  /* dimension  14 */
-	0.381443,  /* dimension  15 */
-	0.235331,  /* dimension  16 */
-	0.140981,  /* dimension  17 */
-	0.082146,  /* dimension  18 */
-	0.046622,  /* dimension  19 */
-	0.025807,  /* dimension  20 */
+const double Xastir_UnitSphereVolumes[] =
+{
+  0.000000,  /* dimension   0 */
+  2.000000,  /* dimension   1 */
+  3.141593,  /* dimension   2 */
+  4.188790,  /* dimension   3 */
+  4.934802,  /* dimension   4 */
+  5.263789,  /* dimension   5 */
+  5.167713,  /* dimension   6 */
+  4.724766,  /* dimension   7 */
+  4.058712,  /* dimension   8 */
+  3.298509,  /* dimension   9 */
+  2.550164,  /* dimension  10 */
+  1.884104,  /* dimension  11 */
+  1.335263,  /* dimension  12 */
+  0.910629,  /* dimension  13 */
+  0.599265,  /* dimension  14 */
+  0.381443,  /* dimension  15 */
+  0.235331,  /* dimension  16 */
+  0.140981,  /* dimension  17 */
+  0.082146,  /* dimension  18 */
+  0.046622,  /* dimension  19 */
+  0.025807,  /* dimension  20 */
 };
 #if NUMDIMS > 20
-#	error "not enough precomputed sphere volumes"
+  # error "not enough precomputed sphere volumes"
 #endif
 #define Xastir_UnitSphereVolume Xastir_UnitSphereVolumes[NUMDIMS]
 
@@ -246,19 +256,24 @@ const double Xastir_UnitSphereVolumes[] = {
  */
 RectReal Xastir_RTreeRectSphericalVolume(struct Rect *R)
 {
-	register struct Rect *r = R;
-	register int i;
-	RectReal maxsize=(RectReal)0, c_size;
+  register struct Rect *r = R;
+  register int i;
+  RectReal maxsize=(RectReal)0, c_size;
 
-	assert(r);
-	if (Undefined(r))
-		return (RectReal)0;
-	for (i=0; i<NUMDIMS; i++) {
-		c_size = r->boundary[i+NUMDIMS] - r->boundary[i];
-		if (c_size > maxsize)
-			maxsize = c_size;
-	}
-	return (RectReal)(pow(maxsize/2, NUMDIMS) * Xastir_UnitSphereVolume);
+  assert(r);
+  if (Undefined(r))
+  {
+    return (RectReal)0;
+  }
+  for (i=0; i<NUMDIMS; i++)
+  {
+    c_size = r->boundary[i+NUMDIMS] - r->boundary[i];
+    if (c_size > maxsize)
+    {
+      maxsize = c_size;
+    }
+  }
+  return (RectReal)(pow(maxsize/2, NUMDIMS) * Xastir_UnitSphereVolume);
 }
 #endif
 
@@ -267,20 +282,23 @@ RectReal Xastir_RTreeRectSphericalVolume(struct Rect *R)
  */
 RectReal Xastir_RTreeRectSphericalVolume(struct Rect *R)
 {
-	register struct Rect *r = R;
-	register int i;
-	register double sum_of_squares=0, radius;
+  register struct Rect *r = R;
+  register int i;
+  register double sum_of_squares=0, radius;
 
-	assert(r);
-	if (Undefined(r))
-		return (RectReal)0;
-	for (i=0; i<NUMDIMS; i++) {
-		double half_extent =
-			(r->boundary[i+NUMDIMS] - r->boundary[i]) / 2;
-		sum_of_squares += half_extent * half_extent;
-	}
-	radius = sqrt(sum_of_squares);
-	return (RectReal)(pow(radius, NUMDIMS) * Xastir_UnitSphereVolume);
+  assert(r);
+  if (Undefined(r))
+  {
+    return (RectReal)0;
+  }
+  for (i=0; i<NUMDIMS; i++)
+  {
+    double half_extent =
+      (r->boundary[i+NUMDIMS] - r->boundary[i]) / 2;
+    sum_of_squares += half_extent * half_extent;
+  }
+  radius = sqrt(sum_of_squares);
+  return (RectReal)(pow(radius, NUMDIMS) * Xastir_UnitSphereVolume);
 }
 
 
@@ -289,26 +307,30 @@ RectReal Xastir_RTreeRectSphericalVolume(struct Rect *R)
 -----------------------------------------------------------------------------*/
 RectReal Xastir_RTreeRectSurfaceArea(struct Rect *R)
 {
-	register struct Rect *r = R;
-	register int i, j;
-	register RectReal sum = (RectReal)0;
+  register struct Rect *r = R;
+  register int i, j;
+  register RectReal sum = (RectReal)0;
 
-	assert(r);
-	if (Undefined(r))
-		return (RectReal)0;
+  assert(r);
+  if (Undefined(r))
+  {
+    return (RectReal)0;
+  }
 
-	for (i=0; i<NUMDIMS; i++) {
-		RectReal face_area = (RectReal)1;
-		for (j=0; j<NUMDIMS; j++)
-			/* exclude i extent from product in this dimension */
-			if(i != j) {
-				RectReal j_extent =
-					r->boundary[j+NUMDIMS] - r->boundary[j];
-				face_area *= j_extent;
-			}
-		sum += face_area;
-	}
-	return 2 * sum;
+  for (i=0; i<NUMDIMS; i++)
+  {
+    RectReal face_area = (RectReal)1;
+    for (j=0; j<NUMDIMS; j++)
+      /* exclude i extent from product in this dimension */
+      if(i != j)
+      {
+        RectReal j_extent =
+          r->boundary[j+NUMDIMS] - r->boundary[j];
+        face_area *= j_extent;
+      }
+    sum += face_area;
+  }
+  return 2 * sum;
 }
 
 
@@ -318,24 +340,28 @@ RectReal Xastir_RTreeRectSurfaceArea(struct Rect *R)
 -----------------------------------------------------------------------------*/
 struct Rect Xastir_RTreeCombineRect(struct Rect *R, struct Rect *Rr)
 {
-	register struct Rect *r = R, *rr = Rr;
-	register int i, j;
-	struct Rect new_rect;
-	assert(r && rr);
+  register struct Rect *r = R, *rr = Rr;
+  register int i, j;
+  struct Rect new_rect;
+  assert(r && rr);
 
-	if (Undefined(r))
-		return *rr;
+  if (Undefined(r))
+  {
+    return *rr;
+  }
 
-	if (Undefined(rr))
-		return *r;
+  if (Undefined(rr))
+  {
+    return *r;
+  }
 
-	for (i = 0; i < NUMDIMS; i++)
-	{
-		new_rect.boundary[i] = MIN(r->boundary[i], rr->boundary[i]);
-		j = i + NUMDIMS;
-		new_rect.boundary[j] = MAX(r->boundary[j], rr->boundary[j]);
-	}
-	return new_rect;
+  for (i = 0; i < NUMDIMS; i++)
+  {
+    new_rect.boundary[i] = MIN(r->boundary[i], rr->boundary[i]);
+    j = i + NUMDIMS;
+    new_rect.boundary[j] = MAX(r->boundary[j], rr->boundary[j]);
+  }
+  return new_rect;
 }
 
 
@@ -344,20 +370,20 @@ struct Rect Xastir_RTreeCombineRect(struct Rect *R, struct Rect *Rr)
 -----------------------------------------------------------------------------*/
 int Xastir_RTreeOverlap(struct Rect *R, struct Rect *S)
 {
-	register struct Rect *r = R, *s = S;
-	register int i, j;
-	assert(r && s);
+  register struct Rect *r = R, *s = S;
+  register int i, j;
+  assert(r && s);
 
-	for (i=0; i<NUMDIMS; i++)
-	{
-		j = i + NUMDIMS;  /* index for high sides */
-		if (r->boundary[i] > s->boundary[j] ||
-		    s->boundary[i] > r->boundary[j])
-		{
-			return FALSE;
-		}
-	}
-	return TRUE;
+  for (i=0; i<NUMDIMS; i++)
+  {
+    j = i + NUMDIMS;  /* index for high sides */
+    if (r->boundary[i] > s->boundary[j] ||
+        s->boundary[i] > r->boundary[j])
+    {
+      return FALSE;
+    }
+  }
+  return TRUE;
 }
 
 
@@ -366,27 +392,31 @@ int Xastir_RTreeOverlap(struct Rect *R, struct Rect *S)
 -----------------------------------------------------------------------------*/
 int Xastir_RTreeContained(struct Rect *R, struct Rect *S)
 {
-	register struct Rect *r = R, *s = S;
-	register int i, j, result;
-	assert(r && s);
+  register struct Rect *r = R, *s = S;
+  register int i, j, result;
+  assert(r && s);
 
- 	// undefined rect is contained in any other
-	//
-	if (Undefined(r))
-		return TRUE;
+  // undefined rect is contained in any other
+  //
+  if (Undefined(r))
+  {
+    return TRUE;
+  }
 
-	// no rect (except an undefined one) is contained in an undef rect
-	//
-	if (Undefined(s))
-		return FALSE;
+  // no rect (except an undefined one) is contained in an undef rect
+  //
+  if (Undefined(s))
+  {
+    return FALSE;
+  }
 
-	result = TRUE;
-	for (i = 0; i < NUMDIMS; i++)
-	{
-		j = i + NUMDIMS;  /* index for high sides */
-		result = result
-			&& r->boundary[i] >= s->boundary[i]
-			&& r->boundary[j] <= s->boundary[j];
-	}
-	return result;
+  result = TRUE;
+  for (i = 0; i < NUMDIMS; i++)
+  {
+    j = i + NUMDIMS;  /* index for high sides */
+    result = result
+             && r->boundary[i] >= s->boundary[i]
+             && r->boundary[j] <= s->boundary[j];
+  }
+  return result;
 }
