@@ -5,25 +5,25 @@
 #ifndef __XASTIR_SHP_HASH_H
 #define __XASTIR_SHP_HASH_H
 
-#ifdef USE_RTREE
 
 #ifdef HAVE_SHAPEFIL_H
-#include <shapefil.h>
+  #include <shapefil.h>
 #else
-#ifdef HAVE_LIBSHP_SHAPEFIL_H
-#include <libshp/shapefil.h>
-#else
-#error HAVE_LIBSHP defined but no corresponding include defined
-#endif  // HAVE_LIBSHP_SHAPEFIL_H
+  #ifdef HAVE_LIBSHP_SHAPEFIL_H
+    #include <libshp/shapefil.h>
+  #else
+    #error HAVE_LIBSHP defined but no corresponding include defined
+  #endif  // HAVE_LIBSHP_SHAPEFIL_H
 #endif  // HAVE_SHAPEFIL_H
 
-typedef struct _shpinfo{
-    char *filename;
-    struct Node* root;
-    time_t creation;
-    time_t last_access;
-    int num_accesses;
-}shpinfo;
+typedef struct _shpinfo
+{
+  char *filename;
+  struct Node* root;
+  time_t creation;
+  time_t last_access;
+  int num_accesses;
+} shpinfo;
 
 void init_shp_hash(int clobber);
 void add_shp_to_hash(char *filename,SHPHandle sHP);
@@ -34,5 +34,4 @@ void destroy_shpinfo(shpinfo *si);
 void purge_shp_hash(time_t secs_now);
 shpinfo *get_shp_from_hash(char *filename);
 
-#endif // USE_RTREE
 #endif // __XASTIR_SHP_HASH_H
