@@ -2,7 +2,7 @@
  *
  * XASTIR, Amateur Station Tracking and Information Reporting
  * Copyright (C) 1999,2000  Frank Giannandrea
- * Copyright (C) 2000-2018 The Xastir Group
+ * Copyright (C) 2000-2019 The Xastir Group
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -31,4 +31,4 @@ char *get_data_base_dir(char *dir);
 void save_data(void);
 void load_data_or_default(void);
 
-char xa_config_dir[1000];       /* cmdline option user config dir */
+extern char xa_config_dir[1000];       /* cmdline option user config dir */
